@@ -21,7 +21,7 @@ def find_local_maxima_at_selected_indexes(array, selected_indexes, \
     # the candidate point by "number_of_points_upto_local_boundary" number of points.
     # It returns values and indexes of the so found local maxima.
     
-    values_of_local_maxima = np.zeros_like(array)
+    array_of_peaks_only = np.zeros_like(array)
     indexes_of_local_maxima = []
     values_of_peak_points=[]
     n =  number_of_points_upto_local_boundary
@@ -46,11 +46,11 @@ def find_local_maxima_at_selected_indexes(array, selected_indexes, \
                 np.max(values_at_all_points_in_surrounding_box)
 
             if (value_at_candidate_point > maximum_value_at_surrounding_points):
-                values_of_local_maxima[i,j] = value_at_candidate_point
+                array_of_peaks_only[i,j] = value_at_candidate_point
                 values_of_peak_points.append(value_at_candidate_point)
                 indexes_of_local_maxima.append(index)
                 
-    return values_of_local_maxima, indexes_of_local_maxima, values_of_peak_points
+    return indexes_of_local_maxima, values_of_peak_points, array_of_peaks_only
 
 
 ###########--------------------------------------------------------------------------
@@ -123,7 +123,7 @@ def check_adjacent_points_for_minimum_current_density \
 
 ##################-------------------------------------------------------------------
 
-def detect_sheet_regions(current_density, indexes_of_local_maxima,ratio_of_jzboundary_to_jzmax):
+def detect_regions_around_peaks(current_density, indexes_of_local_maxima,ratio_of_jzboundary_to_jzmax):
     # This function finds points belonging to current sheets in the "current_density" data.
     # For each index of the local maxima provided in "indexes_of_local_maxima", it stores
     # in a list "indexes_of_points_of_a_cs" the indexes of all the points belonging to the
